summaryrefslogtreecommitdiffstats
path: root/mail/placeholder.h
diff options
context:
space:
mode:
Diffstat (limited to 'mail/placeholder.h')
-rw-r--r--mail/placeholder.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/mail/placeholder.h b/mail/placeholder.h
index 1b2dc71..ffa210c 100644
--- a/mail/placeholder.h
+++ b/mail/placeholder.h
@@ -5,39 +5,39 @@
char *placeholder[] = {
/* name appearing in To: */
- i18n("Mandrakesoft Users"),
+ i18n("Mandriva Users"),
/* subject */
- i18n("Welcome to Mandrakelinux"),
+ i18n("Welcome to Mandriva Linux"),
/* */
- i18n("Welcome to Mandrakelinux!"),
+ i18n("Welcome to Mandriva Linux!"),
/* mail greeting heading */
i18n("Hello,"),
/* */
- i18n("We hope you are totally satisfied with Mandrakelinux. Below is a list of useful websites:"),
+ i18n("We hope you are totally satisfied with Mandriva Linux. Below is a list of useful websites:"),
/* */
- "mandrakesoft.com",
- "http://www.mandrakesoft.com/",
- /* placeholer is mandrakesoft.com URL */
+ "mandriva.com",
+ "http://www.mandriva.com/",
+ /* placeholer is mandriva.com URL */
i18n("The %s website provides all the details for keeping in touch with the publisher of your favorite Linux distribution."),
- i18n("Mandrakestore"),
- "http://www.mandrakestore.com/",
- /* placeholder is 'Mandrakestore' */
- i18n("%s is the Mandrakesoft's online store. Thanks to its new look-and-feel the purchase of products, services or third-party solutions has never been so easy!"),
- i18n("Mandrakeclub"),
- "http://www.mandrakeclub.com/",
- /* placeholder is 'Mandrakeclub' */
+ i18n("Mandriva Store"),
+ "http://www.mandrivastore.com/",
+ /* placeholder is 'Mandriva Store' */
+ i18n("%s is the Mandriva's online store. Thanks to its new look-and-feel the purchase of products, services or third-party solutions has never been so easy!"),
+ i18n("Mandriva Club"),
+ "http://www.mandrivaclub.com/",
+ /* placeholder is 'Mandriva Club' */
i18n("Become a %s member! From special offers to exclusive benefits, %s is the place where users meet and download hundreds of applications."),
- i18n("Mandrakeexpert"),
- "http://www.mandrakeexpert.com/",
- /* placeholder is 'Mandrakeexpert' */
- i18n("%s is the primary destination for receiving assistance from Mandrakesoft's support team."),
- i18n("Mandrakeonline"),
- "http://www.mandrakeeonline.com/",
- /* placeholder is 'Mandrakeonline' */
- i18n("%s is the latest service provided by Mandrakesoft. It allows you to keep your computer up-to-date through a centralized and automated service."),
+ i18n("Mandriva Expert"),
+ "http://www.mandrivaexpert.com/",
+ /* placeholder is 'Mandriva Expert' */
+ i18n("%s is the primary destination for receiving assistance from Mandriva's support team."),
+ i18n("Mandriva Online"),
+ "http://www.mandrivaonline.com/",
+ /* placeholder is 'Mandriva Online' */
+ i18n("%s is the latest service provided by Mandriva. It allows you to keep your computer up-to-date through a centralized and automated service."),
/* goodbye signature (1st line) */
i18n("Yours Sincerely,"),
/* goodbye signature (2nd line) */
- i18n("The Mandrakesoft team"),
+ i18n("The Mandriva team"),
};